==> haskell-lsp-types-1.6.0.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-types
version:              1.6.0.1
visibility:           public
id:                   lsp-types-1.6.0.1-AHKzWPypdwW97w9m48yKB7
key:                  lsp-types-1.6.0.1-AHKzWPypdwW97w9m48yKB7
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  e16ff2cdeadf5459217e18e24271ea0c
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.Types.SMethodMap

hidden-modules:
    Language.LSP.Types.CallHierarchy Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Parsing Language.LSP.Types.Progress
    Language.LSP.Types.Registration Language.LSP.Types.References
    Language.LSP.Types.Rename Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SemanticTokens Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol Language.LSP.Types.Uri.OsPath

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lsp-types-1.6.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lsp-types-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-types
hs-libraries:         HSlsp-types-1.6.0.1-AHKzWPypdwW97w9m48yKB7
depends:
    Diff-0.4.1-DydfvT5aa7cJBcyNonUl9B
    aeson-2.1.2.1-HbpdIbO6AMR9AnrzgnqgHA base-4.16.4.0 binary-0.8.9.0
    containers-0.6.5.1 data-default-0.7.1.1-4Q2QEONQl2rBpJbSE6OFE3
    deepseq-1.4.6.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O exceptions-0.10.4
    filepath-1.4.2.2 hashable-1.4.4.0-BiMdM8DAZvpBwJziK8reqF
    lens-5.2.3-8lYAGRbsVBB5Dn410nzJey
    mod-0.2.0.1-HISE2xwFrCUIGL63iGD5Ad mtl-2.2.2
    network-uri-2.6.4.2-8ohwraftYBVA933qpHaQpI
    safe-0.3.21-6LiAUPzeZ5yE2ECncdJJ3m
    scientific-0.3.7.0-FF6Yj1fy4Cu6vTh2CP6znD
    some-1.0.5-L5glA67mR8RJufLDsA2lRz template-haskell-2.18.0.0
    text-1.2.5.0 unordered-containers-0.2.20-FlJ58vN39MpAJvDCdrVy2C

haddock-interfaces:   /usr/share/doc/haskell-lsp-types/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-types-1.6.0.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-types
version:              1.6.0.1
visibility:           public
id:                   lsp-types-1.6.0.1-2mOBxjHL3U7WYpYgUoZnT
key:                  lsp-types-1.6.0.1-2mOBxjHL3U7WYpYgUoZnT
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  cc15eb652520f4060477305b17cafb4a
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.Types.SMethodMap

hidden-modules:
    Language.LSP.Types.CallHierarchy Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Parsing Language.LSP.Types.Progress
    Language.LSP.Types.Registration Language.LSP.Types.References
    Language.LSP.Types.Rename Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SemanticTokens Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol Language.LSP.Types.Uri.OsPath

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lsp-types-1.6.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lsp-types-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-types
hs-libraries:         HSlsp-types-1.6.0.1-2mOBxjHL3U7WYpYgUoZnT
depends:
    Diff-0.4.1-FQGoMszL7yvHgYjHqpLdBw
    aeson-2.1.2.1-GayFRV4oUv8L6a1HjAAkY base-4.16.4.0 binary-0.8.9.0
    containers-0.6.5.1 data-default-0.7.1.1-4Q2QEONQl2rBpJbSE6OFE3
    deepseq-1.4.6.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O exceptions-0.10.4
    filepath-1.4.2.2 hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    lens-5.2.3-4MTOEd32V8S8DXXehXOq9T
    mod-0.2.0.1-4Mv5ocwd0A3ATaAnGcimET mtl-2.2.2
    network-uri-2.6.4.2-BC3te0GfpncIdQCU8I2AdS
    safe-0.3.21-AbNyMoK0ADF8qenYHSmRn2
    scientific-0.3.7.0-KltKYIXlMCy1e9qM9TkhQF
    some-1.0.5-L5glA67mR8RJufLDsA2lRz template-haskell-2.18.0.0
    text-1.2.5.0 unordered-containers-0.2.20-1oXBHIneMBm69TPTD2tYrr

haddock-interfaces:   /usr/share/doc/haskell-lsp-types/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
